@@ -35,7 +35,7 @@ c("1",
 
 
 ### get rid of the NAMESPACE
-attach(asNamespace("party"))
+attach(list2env(as.list(asNamespace("party"))))
 
 ### 
 ###
